@@ -3,7 +3,8 @@ package ExtUtils::CBuilder::Platform::darwin;
 use strict;
 use ExtUtils::CBuilder::Platform::Unix;
 
-use vars qw(@ISA);
+use vars qw($VERSION @ISA);
+$VERSION = '0.23';
 @ISA = qw(ExtUtils::CBuilder::Platform::Unix);
 
 sub compile {
